@@ -1665,16 +1665,12 @@ def cli(
                             )
                         )
 
+                        # progress bar?
+
                         for user in result.updates[0].peers:
                             try:
                                 user_df = pd.DataFrame(
-                                    locations_list, columns=[
-                                        "User_ID",
-                                        "Distance",
-                                        "Longitude",
-                                        "Latitude",
-                                        "Retrieval_time",
-                                        ]
+                                    locations_list, columns=["User_ID", "Distance"]
                                 )
                                 if hasattr(user, "peer"):
                                     ID = user.peer.user_id
@@ -1685,7 +1681,7 @@ def cli(
                                 else:
                                     pass
 
-                                locations_list.append([ID, distance, longitude, latitude, filetime])
+                                locations_list.append([ID, distance])
 
                             except:
                                 pass
@@ -1695,7 +1691,7 @@ def cli(
                         d_2000 = 0
                         d_3000 = 0
 
-                        for account, distance, longitude, latitude, filetime in user_df.itertuples(index=False):
+                        for account, distance in user_df.itertuples(index=False):
                             account = int(account)
                             my_user = await client.get_entity(PeerUser(account))
                             user_id = my_user.id
@@ -1712,8 +1708,8 @@ def cli(
                                 d_3000 += 1
 
                         with open(
-                            save_file, "a+", encoding="utf-8"
-                        ) as f: 
+                            save_file, "w+", encoding="utf-8"
+                        ) as f:  
                             user_df.to_csv(f, sep=";", index=False)
 
                         total = len(locations_list)
